Modules
Traits
- Handles communication between the game server and the matchmaker. Structs which implement the Communicator trait enable multi-device communication. This means that if a callback is registered with an “on”-function, it may be called when any device calls a “report” or “send” function.